<?php

declare(strict_types=1);

namespace Drupal\navigation_local_tasks\Plugin\Block;

use Drupal\Component\Utility\Html;
use Drupal\Core\Block\Attribute\Block;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\navigation_local_tasks\NavigationLocalTasksBase;

/**
 * Provides a 'local tasks actions' block.
 */
#[Block(
  id: "navigation_local_tasks_actions",
  admin_label: new TranslatableMarkup("Local tasks actions")
)]
final class NavigationLocalTasksActions extends NavigationLocalTasksBase {

  /**
   * {@inheritdoc}
   *
   * @see \Drupal\Core\Menu\Plugin\Block\LocalTasksBlock
   */
  public function build(): array {
    $build = $this->getLocalTasks();

    // @todo Make sure we are returning something sane here. Perhaps
    //  we should attach the lib before returning to make the modification
    //  to the logo available everywhere.
    if (is_null($this->routeMatch->getParameter('node')) || empty($build['#local_tasks'])) {
      unset($build['#local_tasks']);
      return $build;
    }

    // Assemble the build array.
    $details = [
      '#theme' => 'navigation_local_tasks_actions',
      '#title' => $this->configuration['label'],
      '#links' => [],
      '#attached' => [
        'library' => ['navigation_local_tasks/actions'],
      ],
    ];

    foreach ($build['#local_tasks'] as $key => $task) {
      $details['#links'][] = (object) [
        'title' => $task['#link']['title'],
        'url' => $task['#link']['url']->toString(),
        'classes' => [
          'toolbar-button',
          'toolbar-button--icon--' . Html::cleanCssIdentifier(str_replace('.', '-', $key)),
        ],
        'label_class' => 'visually-hidden',
      ];
    }

    // Add additional classes to the first link.
    $first = reset($details['#links']);
    $first->label_class = 'toolbar-button__label';
    $first->classes[] = 'toolbar-button--collapsible';

    return $build + $details;
  }

}
